##  Description
In SAP LeanIX, we apply a business-oriented view of interfaces, and they are between applications. The interface fact sheet addresses fundamental questions about how data objects are exchanged and how applications are interconnected. It relies on IT components (software, hardware, or service) to function. You can capture data flow directions, type of transfer, and frequency with the interface fact sheet.
This business-oriented view enables organizations to gain valuable insights into their technology landscape and understand how different components interact.
Overview of all relations to/from interfaces:
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274862707a4410148e8e8b61e7a46ae6_LowRes.png)
You may model middleware (integration platform), Enterprise Service Bus (ESB), and APIs using the interface fact sheet by implementing relations between the interface and the IT components or applications.
Interfaces are implemented via IT components, data objects, and attributes on the fact sheet.
